@@ -7,7 +7,7 @@ use POSIX qw/ceil floor/;
 use Scalar::Util 'looks_like_number';
 require Exporter;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 our @ISA = 'Exporter';
 our @EXPORT_OK = 'calc';
 our $ERROR;
@@ -86,7 +86,7 @@ our $ERROR;
 		rand  => { args => 0, code => sub { rand } },
 	);
 	
-	sub _default_functions { \%functions }
+	sub _default_functions { +{%functions} }
 }
 
 sub new {
